package ru.indvdum.mywork.vaadin;

import static ru.indvdum.mywork.MyWork.EM;
import ru.indvdum.mywork.openjpa.model.Task;

import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Label;
import com.vaadin.ui.RichTextArea;
import com.vaadin.ui.TextField;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.Window;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.Button.ClickListener;

public class EditTaskDialog extends Window implements ClickListener {
	
	private MyWorkApplication myApp = null;
	private EditState state = null;
	private Task task = null;
	private TextField taskName = null;
	private RichTextArea taskDescription = null;

	public EditTaskDialog(MyWorkApplication myApp, EditState state, Task task) throws Exception {
		super();
		this.myApp = myApp;
		this.state = state;
		switch(state){
		case CREATE:
			setCaption("Creating new task");
			if(task != null)
				throw new Exception("Illegal argument: task must be null in creating state.");
			task = new Task();
			task.setName("");
			task.setDescription("");
			this.task = task;
			break;
		case EDIT:
			setCaption("Editing task");
			if(task == null)
				throw new Exception("Illegal argument: task must be not null in editing state.");
			this.task = task;
			break;
		}
		init();
	}
	
	private void init(){
		setModal(true);
		setWidth("640px");
		setHeight("480px");
		VerticalLayout vl = new VerticalLayout();
		vl.setSizeFull();
		vl.setSpacing(true);
		vl.setMargin(true);
		setContent(vl);
		
		HorizontalLayout hlName = new HorizontalLayout();
		hlName.setWidth("100%");
		Label lblName = new Label("Name:");
		lblName.setWidth("100%");
		hlName.addComponent(lblName);
		hlName.setExpandRatio(lblName, 1f);
		taskName = new TextField();
		taskName.setWidth("100%");
		taskName.setValue(task.getName());
		hlName.addComponent(taskName);
		hlName.setExpandRatio(taskName, 5f);
		vl.addComponent(hlName);
		
		taskDescription = new RichTextArea("Description");
		taskDescription.setValue(task.getDescription());
		taskDescription.setSizeFull();
		vl.addComponent(taskDescription);
		vl.setExpandRatio(taskDescription, 1f);
		
		HorizontalLayout hlOk = new HorizontalLayout();
		hlOk.setWidth("100%");
		Button okButton = new Button();
		switch(state){
		case CREATE:
			okButton.setCaption("Create");
			break;
		case EDIT:
			okButton.setCaption("Save");
			break;
		}
		okButton.addListener((ClickListener)this);
		hlOk.addComponent(okButton);
		hlOk.setComponentAlignment(okButton, Alignment.MIDDLE_RIGHT);
		vl.addComponent(hlOk);
	}

	@Override
	public void buttonClick(ClickEvent event) {
		task.setName(taskName.getValue().toString());
		task.setDescription(taskDescription.getValue().toString());
		try{
			EM.getTransaction().begin();
			EM.persist(task);
			EM.getTransaction().commit();
		} finally {
			if(EM.getTransaction().isActive())
				EM.getTransaction().rollback();
		}
		getParent().removeWindow(this);
		myApp.getTaskTable().requestRepaint();
	}

}
